/*
 * Copyright (c) 2012 by Tuomo Syvnper
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License (LGPL) as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, copies are available
 * at http://www.opensource.org.
 */

package net.tollot.vassal.SCS;

import java.awt.Point;

import VASSAL.build.GameModule;
import VASSAL.command.Command;
import VASSAL.counters.GamePiece;
import VASSAL.counters.Stack;

/**
 * Specialized Stack implementation for SCS games by MMP.
 * 
 * Shows only the topmost unit of the stack and hides others until an attack is declared against the
 * stack.
 * 
 * @author Tuomo Syvnper
 */
public class SCSStack extends Stack {
    public SCSStack() {
        super();
    }

    public SCSStack(GamePiece p) {
        super(p);
    }
    
    @Override
    public void add(GamePiece p) {
        GameModule.getGameModule().getChatter().show("SCSStack.add(): " + p.getName());
        super.add(p);
    }

	@Override
	public void remove(GamePiece p) {
        GameModule.getGameModule().getChatter().show("SCSStack.remove(): " + p.getName());
		super.remove(p);
	}

	@Override
	protected void removePieceAt(int index) {
        GameModule.getGameModule().getChatter().show("SCSStack.removePieceAt(): " + index);
		super.removePieceAt(index);
	}

	@Override
	public Command pieceRemoved(GamePiece p) {
        GameModule.getGameModule().getChatter().show("SCSStack.pieceRemoved(): " + p.getName());
		return super.pieceRemoved(p);
	}

	@Override
	protected void insertPieceAt(GamePiece p, int index) {
        GameModule.getGameModule().getChatter().show("SCSStack.insertPieceAt(): " + index + ": " + p.getName());
		super.insertPieceAt(p, index);
	}

	@Override
	public void insertChild(GamePiece child, int index) {
        GameModule.getGameModule().getChatter().show("SCSStack.insertChild(): " + index + ": " + child.getName());
		super.insertChild(child, index);
	}

	@Override
	public void insert(GamePiece p, int pos) {
        GameModule.getGameModule().getChatter().show("SCSStack.insert(): " + pos + ": " + p.getName());
		super.insert(p, pos);
	}

	@Override
	public Command pieceAdded(GamePiece p) {
        GameModule.getGameModule().getChatter().show("SCSStack.pieceAdded(): " + p.getName());
		return super.pieceAdded(p);
	}

	@Override
	public void setExpanded(boolean b) {
        GameModule.getGameModule().getChatter().show("SCSStack.setExpanded(): " + b);
		super.setExpanded(b);
	}

	@Override
	public void setPosition(Point p) {
        GameModule.getGameModule().getChatter().show("SCSStack.setPosition(): " + p.toString());
		super.setPosition(p);
	}
}